@@ -22,7 +22,7 @@ from enum import Enum
 
 from arjuna.tpi.helper.arjtype import CIStringDict
 from arjuna.tpi.constant import ArjunaOption
-from arjuna.core.yaml import Yaml
+from arjuna.tpi.parser.yaml import Yaml
 from .validator import Validator
 from enum import Enum
 from arjuna.tpi.constant import BrowserName
@@ -114,7 +114,7 @@ class ArjunaOptions(Options):
         my_dir = os.path.dirname(os.path.realpath(__file__))
         desc_file = os.path.abspath(os.path.join(my_dir, "..", "res", "arjuna_conf_desc.yaml"))
         creation_context=f"This Yaml represents arjuna_conf_desc.yaml configuration file at {desc_file} that describes rules for Arjuna's built-in options."
-        desc_yaml = Yaml.from_file(file_path=desc_file)
+        desc_yaml = Yaml.from_file(desc_file)
         cls.ARJUNA_OPTIONS_DESC_MAP = {cls.process_arjuna_option_name(k): v for k, v in desc_yaml.as_map().items()}
 
     def __init__(self, *, options_dict, creation_context, validate=True):
@@ -260,15 +260,25 @@ class EditableConfig:
         for rname, rvalue in replacements.items():
             contents = contents.replace("${}$".format(rname), rvalue)
         
-        contents_yaml = Yaml.from_str(name="arjuna_defaults", contents=contents)
+        contents_yaml = Yaml.from_str(contents)
 
         return cls.from_yaml(yaml_obj=contents_yaml, creation_context=creation_context, validate=validate)
 
     @classmethod
     def from_yaml(cls, *, yaml_obj, creation_context, validate=True):
+        arjuna_options_dict = yaml_obj.get_section("arjuna_options", strict=False, allow_any=True)
+        if arjuna_options_dict is not None:
+            arjuna_options_dict = arjuna_options_dict.as_map()
+        else:
+            arjuna_options_dict = dict()        
+        user_options_dict = yaml_obj.get_section("user_options", strict=False, allow_any=True)
+        if user_options_dict is not None:
+            user_options_dict = user_options_dict.as_map()
+        else:
+            user_options_dict = dict()
         return EditableConfig(
-            arjuna_options_dict = yaml_obj.get_section("arjuna_options", strict=False).as_map(),
-            user_options_dict = yaml_obj.get_section("user_options", strict=False).as_map(),
+            arjuna_options_dict = arjuna_options_dict,
+            user_options_dict = user_options_dict,
             creation_context = "This configuration represents " + creation_context,
             validate=validate
         )
@@ -312,10 +322,11 @@ class EditableConfig:
 
     @classmethod
     def __multi_confs_file(cls, *, file_path, creation_context):
-        data_yaml = Yaml.from_file(file_path=file_path)
+        yaml = Yaml.from_file(file_path, allow_any=True)
         conf_map = dict()
-        for section_name in data_yaml.section_names:
-            conf_map[section_name] = cls.from_yaml(yaml_obj=data_yaml.get_section(section_name), creation_context=f"Section {section_name} in {creation_context}")
+        if yaml is not None:
+            for section_name in yaml.section_names:
+                conf_map[section_name] = cls.from_yaml(yaml_obj=yaml.get_section(section_name), creation_context=f"Section {section_name} in {creation_context}")
 
         return conf_map
 
