@@ -298,9 +298,9 @@ class ReportFormat(Enum):
     XML = auto()
     HTML = auto()
 
-class DataRefContextType(Enum):
-    ROW = auto()
-    COLUMN = auto()
+class DataRefType(Enum):
+    CONTEXTUAL = auto()
+    INDEXED = auto()
 
 class LoggingLevel(Enum):
     TRACE = auto()
