@@ -22,7 +22,7 @@ from .reference import ContextualDataReference
 from arjuna.tpi.helper.arjtype import CIStringDict
 
 from arjuna.core.utils import file_utils
-from arjuna.tpi.helper.json import Json, JsonDict
+from arjuna.tpi.parser.json import Json, JsonDict
 
 class L10NRef:
 
@@ -75,7 +75,7 @@ class ExcelL10NRef(L10NRef):
 
     def __init__(self, fpath):
         super().__init__()
-        excel_ref = DataReference.create_excel_column_data_ref(fpath)
+        excel_ref = DataReference.create_contextual_data_ref(fpath)
         self.map = excel_ref.map
 
 class JsonL10NRef(L10NRef):
@@ -86,7 +86,7 @@ class JsonL10NRef(L10NRef):
         fnames = os.listdir(ldir)
         fnames.sort()
         for fname in fnames:
-            if fname.lower().endswith("json"):
+            if fname.lower().endswith(".json"):
                 lang = os.path.splitext(fname)[0].replace("-","_").lower()
                 fpath = self.get_localizer_file_path(ldir, fname)
                 try:
@@ -155,27 +155,25 @@ class Localizer:
     @classmethod
     def load_all(cls, ref_config):
         from arjuna.tpi.constant import ArjunaOption
-        l10n_excel_dir = ref_config.value(ArjunaOption.L10N_EXCEL_DIR)
+        l10n_dir = ref_config.value(ArjunaOption.L10N_DIR)
         l10n_merged_ref = L10NRef()
         l10n_refs = Localizers()
-        if os.path.isdir(l10n_excel_dir):
-            fnames = os.listdir(l10n_excel_dir)
+        if os.path.isdir(l10n_dir):
+            fnames = os.listdir(l10n_dir)
             fnames.sort()
             for fname in fnames:
                 if fname.lower().endswith("xls"):
-                    ref = ExcelL10NRef(os.path.join(l10n_excel_dir, fname))
+                    ref = ExcelL10NRef(os.path.join(l10n_dir, fname))
                     l10n_merged_ref.update_from_excel_ref(ref)
                     l10n_refs[os.path.splitext(fname)[0]] = ref
 
-        # JSON Localizers
-        l10n_json_dir = ref_config.value(ArjunaOption.L10N_JSON_DIR)
-        if os.path.isdir(l10n_json_dir):
-            json_ref = JsonL10NRef(l10n_json_dir)
+        if os.path.isdir(l10n_dir):        
+            json_ref = JsonL10NRef(l10n_dir)
             cls.__process_json_ref(l10n_merged_ref, l10n_refs, json_ref, bucket="root")
-            buckets = os.listdir(l10n_json_dir)
+            buckets = os.listdir(l10n_dir)
             for bucket in buckets:
-                if os.path.isdir(os.path.join(l10n_json_dir, bucket)):
-                    dpath = os.path.join(l10n_json_dir, bucket)
+                if os.path.isdir(os.path.join(l10n_dir, bucket)):
+                    dpath = os.path.join(l10n_dir, bucket)
                     json_ref = JsonL10NRef(dpath)
                     cls.__process_json_ref(l10n_merged_ref, l10n_refs, json_ref, bucket=bucket)
 
