@@ -16,8 +16,8 @@
 # limitations under the License.
 
 import abc
-from arjuna.core.exceptions import WaitableError, _GuiWidgetPresentError
-from arjuna.tpi.exceptions import GuiWidgetNotFoundError
+from arjuna.core.error import WaitableError, _GuiWidgetPresentError
+from arjuna.tpi.error import GuiWidgetNotFoundError
 
 class ElementFinder:
     def __init__(self, container): #, obj_name=""):
