@@ -1,21 +1,19 @@
-'''
-This file is a part of Arjuna
-Copyright 2015-2020 Rahul Verma
+# This file is a part of Arjuna
+# Copyright 2015-2020 Rahul Verma
 
-Website: www.RahulVerma.net
+# Website: www.RahulVerma.net
 
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 
-  http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-'''
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 
 from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
@@ -50,15 +48,15 @@ class BrowserLauncher:
         caps = DesiredCapabilities.CHROME
         caps.update(config["driverCapabilities"])
 
-        if config["arjunaOptions"]["BROWSER_PROXY_ON"]:
-            proxy = Proxy()
-            proxy_string = "{}.{}".format(
-                config["arjunaOptions"]["BROWSER_PROXY_HOST"],
-                config["arjunaOptions"]["BROWSER_PROXY_PORT"]
-            )
-            proxy.http_proxy = proxy_string
-            proxy.ssl_proxy = proxy_string
-            proxy.add_to_capabilities(caps)
+        # if config["arjunaOptions"]["BROWSER_PROXY_ON"]:
+        #     proxy = Proxy()
+        #     proxy_string = "{}.{}".format(
+        #         config["arjunaOptions"]["BROWSER_PROXY_HOST"],
+        #         config["arjunaOptions"]["BROWSER_PROXY_PORT"]
+        #     )
+        #     proxy.http_proxy = proxy_string
+        #     proxy.ssl_proxy = proxy_string
+        #     proxy.add_to_capabilities(caps)
 
         options = ChromeOptions()
 
@@ -90,15 +88,15 @@ class BrowserLauncher:
         from selenium.webdriver import FirefoxProfile
 
         profile = FirefoxProfile()
-        if config["arjunaOptions"]["BROWSER_PROXY_ON"]:
-            proxy = Proxy()
-            proxy_string = "{}.{}".format(
-                config["arjunaOptions"]["BROWSER_PROXY_HOST"],
-                config["arjunaOptions"]["BROWSER_PROXY_PORT"]
-            )
-            proxy.http_proxy = proxy_string
-            proxy.ssl_proxy = proxy_string
-            profile.set_proxy(proxy)
+        # if config["arjunaOptions"]["BROWSER_PROXY_ON"]:
+        #     proxy = Proxy()
+        #     proxy_string = "{}.{}".format(
+        #         config["arjunaOptions"]["BROWSER_PROXY_HOST"],
+        #         config["arjunaOptions"]["BROWSER_PROXY_PORT"]
+        #     )
+        #     proxy.http_proxy = proxy_string
+        #     proxy.ssl_proxy = proxy_string
+        #     profile.set_proxy(proxy)
 
         caps = DesiredCapabilities.FIREFOX
         caps.update(config["driverCapabilities"])
