@@ -187,11 +187,11 @@ class YamlGnsLoader(BaseGuiNamespaceLoader):
         from arjuna import Arjuna
         from arjuna.configure.validator import Validator
         from arjuna.interact.gui.auto.finder._with import WithType
-        from arjuna.core.yaml import Yaml
+        from arjuna.tpi.parser.yaml import Yaml
         creation_context="Gui Namespace file at {}".format(self.__ns_path)
-        yaml = Yaml.from_file(file_path=self.__ns_path)
+        yaml = Yaml.from_file(self.__ns_path, allow_any=True)
 
-        if yaml.is_empty(): return
+        if yaml is None: return
 
         if not yaml.has_section("labels"):
             # print("No labels configured. Skipping...")
