@@ -115,11 +115,9 @@ class CreateProject(Command):
         (FileObjectType.DIR, "data"),
         (FileObjectType.DIR, "data/source"),
         (FileObjectType.DIR, "data/reference"),
-        (FileObjectType.DIR, "data/reference/excel_column"),
-        (FileObjectType.DIR, "data/reference/excel_row"),
+        (FileObjectType.DIR, "data/reference/contextual"),
+        (FileObjectType.DIR, "data/reference/indexed"),
         (FileObjectType.DIR, "l10n"),
-        (FileObjectType.DIR, "l10n/excel"),
-        (FileObjectType.DIR, "l10n/json"),
         (FileObjectType.DIR, "guiauto"),
         (FileObjectType.DIR, "guiauto/driver"),
         (FileObjectType.DIR, "guiauto/driver/linux"),
@@ -136,11 +134,7 @@ class CreateProject(Command):
         (FileObjectType.FILE, "test/pkg/__init__.py"),
         (FileObjectType.DIR, "lib"),
         (FileObjectType.FILE, "lib/__init__.py"),
-        (FileObjectType.DIR, "lib/resource"),
-        (FileObjectType.FILE, "lib/resource/__init__.py"),
-        (FileObjectType.FILE, "lib/resource/group.py"),
-        (FileObjectType.FILE, "lib/resource/module.py"),
-        (FileObjectType.FILE, "lib/resource/test.py"),
+        (FileObjectType.FILE, "lib/resource.py")
     )
 
     def __init__(self, subparsers, parents):
