@@ -23,7 +23,7 @@ These types are used for annotating functions, methods and return types.
 In future, they could be used to enforce types. For the time being, the purpose is understandability and documentation.
 '''
 from typing import TypeVar
-from arjuna.tpi.enums import ArjunaOption
+from arjuna.tpi.constant import ArjunaOption
 
 ListOrTuple = TypeVar('ListOrTuple', list, tuple)
 ArjunaOptionOrStr = TypeVar('ArjunaOptionOrStr', ArjunaOption, str)
\ No newline at end of file
