@@ -58,7 +58,8 @@ class ArjunaSingleton:
 
         self.dl = None
         self.log_file_discovery_info = False
-        self.__data_references = None
+        self.__contextual_data_references = None
+        self.__indexed_data_references = None
         self.__logger = None
         from arjuna.engine.data.store import DataStore
         self.__data_store = DataStore()
@@ -120,18 +121,20 @@ class ArjunaSingleton:
 
         # Load data references
         from arjuna.engine.data.factory import DataReference
-        self.__data_references = DataReference.load_all(self.ref_config)
+        self.__contextual_data_references, self.__indexed_data_references  = DataReference.load_all(self.ref_config)
 
         # Load localization data
         from arjuna.engine.data.localizer import Localizer
         self.__localizer = Localizer.load_all(self.ref_config)
 
-        from arjuna.core.yaml import Yaml
+        from arjuna.tpi.parser.yaml import Yaml
         from arjuna.interact.gui.auto.finder.withx import WithX
         fpath = self.ref_config.value(ArjunaOption.CONF_WITHX_FILE)
         creation_context= f"WithX.yaml file at {fpath}"
         if os.path.isfile(fpath):        
-            self.__common_withx_ref = WithX(Yaml.from_file(file_path=fpath).as_map())
+            wyaml = Yaml.from_file(fpath, allow_any=True)
+            if wyaml is not None:
+                self.__common_withx_ref = WithX(wyaml.as_map())
 
         return self.ref_config
 
@@ -144,8 +147,12 @@ class ArjunaSingleton:
         return self.__common_withx_ref
 
     @property
-    def data_references(self):
-        return self.__data_references
+    def contextual_data_references(self):
+        return self.__contextual_data_references
+
+    @property
+    def indexed_data_references(self):
+        return self.__indexed_data_references
 
     @property
     def localizer(self):
@@ -292,12 +299,22 @@ class Arjuna:
         return cls.ARJUNA_SINGLETON.get_config_value(query, cname=cname)
 
     @classmethod
-    def get_dataref_value(cls, name, *, bucket=None, context=None):
+    def get_data_ref(cls, name):
+        try:
+            return cls.ARJUNA_SINGLETON.contextual_data_references[name]
+        except:
+            try:
+                return cls.ARJUNA_SINGLETON.indexed_data_references[name]
+            except:
+                raise Exception(f"No data reference found with name: {name}")
+
+    @classmethod
+    def get_dataref_value(cls, query="", *, bucket=None, context=None, index=None):
         '''
             Returns the data reference value for a given context.
         '''
         from arjuna.engine.data.reference import R
-        return R(name, bucket=bucket, context=context)
+        return R(query, bucket=bucket, context=context, index=index)
 
     @classmethod
     def get_report_metadata(cls):
@@ -314,10 +331,6 @@ class Arjuna:
     def get_localizer(cls):
         return cls.ARJUNA_SINGLETON.localizer
 
-    @classmethod
-    def get_data_ref(cls, name):
-        return cls.ARJUNA_SINGLETON.data_references[name]
-
     @classmethod
     def get_localized_str(cls, in_str, *, locale=None, bucket=None, strict=None):
         from arjuna.engine.data.localizer import L
